"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GerritService = void 0;
const gerrit_api_1 = require("./gerrit.api");
class GerritService {
    constructor(inputs) {
        this.gerritApi = new gerrit_api_1.GerritApi(inputs);
        this.inputs = inputs;
    }
    async getPullRequestsWithCommits(repo) {
        try {
            const prs = await this.gerritApi.getChanges(repo);
            return Promise.all(prs.map(async (pr) => {
                const info = await this.gerritApi.getCommitsInfo(repo, pr);
                const result = {
                    ...info,
                    prDate: pr.updated || pr.created,
                    number: pr._number,
                    url: `${this.inputs.gerritHost}/c/${repo}/+/${pr._number}`,
                    title: pr.subject,
                    targetBranch: pr.branch
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo) {
        const gerritChangeInfo = await this.gerritApi.getChange(repo);
        if (!gerritChangeInfo) {
            return null;
        }
        const currentRevision = gerritChangeInfo?.revisions[gerritChangeInfo?.current_revision];
        return {
            name: gerritChangeInfo.branch,
            commit: currentRevision.commit.message,
            commitMsg: currentRevision.commit.message,
            commitURL: `${this.inputs.gerritHost}${currentRevision.commit.web_links[0].url}`,
            committerUsername: currentRevision.commit.committer.name || currentRevision.commit.committer.email
        };
    }
}
exports.GerritService = GerritService;
//# sourceMappingURL=gerrit.service.js.map