"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GithubService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const github_api_1 = require("./github.api");
class GithubService {
    constructor(inputs) {
        this.githubApi = new github_api_1.GithubApi(inputs);
    }
    async getCommitsInfo(repo, number) {
        return this.githubApi.getCommitsInfo(repo, number);
    }
    async getPullRequestsWithCommits(repo, branch) {
        try {
            const searchResult = await this.githubApi.searchForPullRequests(repo, branch);
            return Promise.all(searchResult.items.map(async (foundItem) => {
                const commitsInfo = await this.githubApi.getCommitsInfo(repo, foundItem.number);
                const result = {
                    ...commitsInfo,
                    prDate: foundItem.closed_at || foundItem.updated_at,
                    number: foundItem.number,
                    url: foundItem.pull_request.html_url,
                    title: foundItem.title,
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, branch, revision) {
        try {
            const githubBranch = await this.githubApi.getBranch(repo, branch);
            let commitByRevision;
            if (revision && githubBranch.commit.sha !== revision) {
                console.log(`Getting commit by revision ${revision}`);
                commitByRevision = await this.githubApi.getCommit(repo, branch, revision)
                    .catch(error => console.error(`Can't get commit by revision ${revision}. Using branch. ${error.message}`));
            }
            const commit = commitByRevision || githubBranch.commit;
            return {
                name: githubBranch.name,
                commit: commit.sha,
                commitMsg: commit.commit.message,
                commitURL: commit.html_url,
                committerUsername: commit.author.login
            };
        }
        catch (error) {
            if (lodash_1.default.get(error, 'status') === 404) {
                return;
            }
            throw new Error(`failed to get branch: ${error.message}`);
        }
    }
}
exports.GithubService = GithubService;
//# sourceMappingURL=github.service.js.map